@@ -14,7 +14,7 @@ NxsString contData(NxsCharactersBlock& charBlock, NxsString& charString,
 	}
 	else {
 	    char buffer[100];
-	    sprintf(buffer, "%.10f", state);
+	    snprintf(buffer, sizeof(buffer), "%.10f", state);
 	    charString+=buffer;
 	}
 
@@ -73,7 +73,7 @@ Rcpp::List RNCL (SEXP params, SEXP paramsVecR) {
 
     bool charall = paramsVec[0];
     bool polyconvert = paramsVec[1];
-    bool levelsUnif = paramsVec[2];
+    //bool levelsUnif = paramsVec[2];
     bool returnTrees = paramsVec[3];
     bool returnData = paramsVec[4];
 
